@@ -45,32 +45,79 @@
 
 #ifndef HAVE_MKDTEMP
 #include "mkdtemp.h"
-#endif                                        
-                                            
+#endif
+
 #define BUF_SIZE 4096
 
 
 gboolean
-path_is_file (const gchar *path)
+path_exists (const gchar *path)
 {
 	GnomeVFSFileInfo *info;
 	GnomeVFSResult result;
-	gboolean is_file;
+	gboolean exists;
 	gchar *escaped;
 
-	if (! path || ! *path) return FALSE; 
+	if (! path || ! *path) return FALSE;
 
 	info = gnome_vfs_file_info_new ();
 	escaped = gnome_vfs_escape_path_string (path);
-	result = gnome_vfs_get_file_info (escaped, 
-					  info, 
-					  (GNOME_VFS_FILE_INFO_DEFAULT 
+	result = gnome_vfs_get_file_info (escaped,
+					  info,
+					  (GNOME_VFS_FILE_INFO_DEFAULT
+					   | GNOME_VFS_FILE_INFO_FOLLOW_LINKS));
+
+	exists = (result == GNOME_VFS_OK);
+
+	g_free (escaped);
+	gnome_vfs_file_info_unref (info);
+
+	return exists;
+}
+
+
+gboolean
+uri_exists (const char  *uri)
+{
+	GnomeVFSFileInfo *info;
+	GnomeVFSResult    result;
+	gboolean          exists;
+
+	if (uri == NULL) 
+		return FALSE;
+
+	info = gnome_vfs_file_info_new ();
+	result = gnome_vfs_get_file_info (uri,
+					  info,
+					  GNOME_VFS_FILE_INFO_DEFAULT);
+
+	exists = (result == GNOME_VFS_OK);
+
+	gnome_vfs_file_info_unref (info);
+
+	return exists;	
+}
+
+
+gboolean
+path_is_file (const char *uri)
+{
+	GnomeVFSFileInfo *info;
+	GnomeVFSResult    result;
+	gboolean          is_file;
+
+	if (! uri || ! *uri)
+		return FALSE;
+
+	info = gnome_vfs_file_info_new ();
+	result = gnome_vfs_get_file_info (uri,
+					  info,
+					  (GNOME_VFS_FILE_INFO_DEFAULT
 					   | GNOME_VFS_FILE_INFO_FOLLOW_LINKS));
 	is_file = FALSE;
-	if (result == GNOME_VFS_OK)		
+	if (result == GNOME_VFS_OK)
 		is_file = (info->type == GNOME_VFS_FILE_TYPE_REGULAR);
-	
-	g_free (escaped);
+
 	gnome_vfs_file_info_unref (info);
 
 	return is_file;
@@ -78,26 +125,24 @@ path_is_file (const gchar *path)
 
 
 gboolean
-path_is_dir (const gchar *path)
+path_is_dir (const char *uri)
 {
 	GnomeVFSFileInfo *info;
-	GnomeVFSResult result;
-	gboolean is_dir;
-	gchar *escaped;
+	GnomeVFSResult    result;
+	gboolean          is_dir;
 
-	if (! path || ! *path) return FALSE; 
+	if (! uri || ! *uri)
+		return FALSE;
 
 	info = gnome_vfs_file_info_new ();
-	escaped = gnome_vfs_escape_path_string (path);
-	result = gnome_vfs_get_file_info (escaped, 
-					  info, 
-					  (GNOME_VFS_FILE_INFO_DEFAULT 
+	result = gnome_vfs_get_file_info (uri,
+					  info,
+					  (GNOME_VFS_FILE_INFO_DEFAULT
 					   | GNOME_VFS_FILE_INFO_FOLLOW_LINKS));
 	is_dir = FALSE;
 	if (result == GNOME_VFS_OK)
 		is_dir = (info->type == GNOME_VFS_FILE_TYPE_DIRECTORY);
-	
-	g_free (escaped);
+
 	gnome_vfs_file_info_unref (info);
 
 	return is_dir;
@@ -132,144 +177,171 @@ dir_is_empty (const char *path)
 
 
 gboolean
-dir_contains_one_object (const char *path)
+dir_contains_one_object (const char *uri)
 {
-	DIR *dp;
-	int  n;
-
-	if (path == NULL)
+	GnomeVFSDirectoryHandle *handle;
+	GnomeVFSResult           result;
+	int                      n;
+	GnomeVFSFileInfo         info;
+	
+	result = gnome_vfs_directory_open (&handle, uri, GNOME_VFS_FILE_INFO_DEFAULT);
+	if (result != GNOME_VFS_OK)
 		return FALSE;
-
-	if (strcmp (path, "/") == 0)
-		return FALSE;
-
-	dp = opendir (path);
-	if (dp == NULL)
-		return FALSE;
-
+		
 	n = 0;
-	while (readdir (dp) != NULL) {
-		n++;
-		if (n > 3) {
-			closedir (dp);
-			return FALSE;
-		}
+	while (gnome_vfs_directory_read_next (handle, &info) == GNOME_VFS_OK) {
+		if ((strcmp (info.name, ".") == 0) || (strcmp (info.name, "..") == 0))
+			continue;
+		if (++n > 1) 
+			break;
 	}
-	closedir (dp);
 
-	return TRUE;
+	gnome_vfs_directory_close (handle);
+	
+	return (n == 1);
 }
 
 
-gboolean 
-dir_is_temp_dir (const char *dir) {
-	const char *tmp_dir = g_get_tmp_dir ();
-	return (strncmp (dir, tmp_dir, strlen (tmp_dir)) == 0);
-}
-
-
-/* Check whether the path_src is contained in path_dest */
-gboolean
-path_in_path (const char  *path_src,
-	      const char  *path_dest)
+char *
+get_directory_content_if_unique (const char  *uri)
 {
-	int path_src_l, path_dest_l;
-
-	if ((path_src == NULL) || (path_dest == NULL))
-		return FALSE;
+	GnomeVFSDirectoryHandle *handle;
+	GnomeVFSResult           result;
+	GnomeVFSFileInfo        *info;
+	char                    *content_uri = NULL;
 	
-	path_src_l = strlen (path_src);
-	path_dest_l = strlen (path_dest);
+	result = gnome_vfs_directory_open (&handle, uri, GNOME_VFS_FILE_INFO_DEFAULT);
+	if (result != GNOME_VFS_OK)
+		return NULL;
 	
-	return ((path_dest_l > path_src_l)
-		&& (strncmp (path_src, path_dest, path_src_l) == 0)
-		&& ((path_src_l == 1) || (path_dest[path_src_l] == '/')));
+	info = gnome_vfs_file_info_new ();
+	while (gnome_vfs_directory_read_next (handle, info) == GNOME_VFS_OK) {
+		if ((strcmp (info->name, ".") == 0) || (strcmp (info->name, "..") == 0))
+			continue;
+		if (content_uri != NULL) {
+			g_free (content_uri);
+			content_uri = NULL;
+			break;
+		}
+		else
+			content_uri = g_strconcat (uri, "/", info->name, NULL);
+	}
+	gnome_vfs_file_info_unref (info);
+	gnome_vfs_directory_close (handle);
+	
+	return content_uri;	
 }
 
 
-GnomeVFSFileSize 
-get_file_size (const gchar *path)
+/* Check whether the dirname is contained in filename */
+gboolean
+path_in_path (const char *dirname,
+	      const char *filename)
+{
+	int dirname_l, filename_l, separator_position;
+
+	if ((dirname == NULL) || (filename == NULL))
+		return FALSE;
+
+	dirname_l = strlen (dirname);
+	filename_l = strlen (filename);
+
+	if ((dirname_l == filename_l + 1)
+	     && (dirname[dirname_l - 1] == '/'))
+		return FALSE;
+
+	if ((filename_l == dirname_l + 1)
+	     && (filename[filename_l - 1] == '/'))
+		return FALSE;
+
+	if (dirname[dirname_l - 1] == '/')
+		separator_position = dirname_l - 1;
+	else
+		separator_position = dirname_l;
+
+	return ((filename_l > dirname_l)
+		&& (strncmp (dirname, filename, dirname_l) == 0)
+		&& (filename[separator_position] == '/'));
+}
+
+
+GnomeVFSFileSize
+get_file_size (const char *uri)
 {
 	GnomeVFSFileInfo *info;
-	GnomeVFSResult result;
-	GnomeVFSFileSize size;
-	gchar *escaped;
+	GnomeVFSResult    result;
+	GnomeVFSFileSize  size;
 
-	if (! path || ! *path) return 0; 
+	if ((uri == NULL) || (*uri == '\0'))
+		return 0;
 
 	info = gnome_vfs_file_info_new ();
-	escaped = gnome_vfs_escape_path_string (path);
-	result = gnome_vfs_get_file_info (escaped, 
+	result = gnome_vfs_get_file_info (uri,
 					  info,
-					  (GNOME_VFS_FILE_INFO_DEFAULT 
-					   | GNOME_VFS_FILE_INFO_FOLLOW_LINKS)); 
+					  (GNOME_VFS_FILE_INFO_DEFAULT
+					   | GNOME_VFS_FILE_INFO_FOLLOW_LINKS));
 	size = 0;
 	if (result == GNOME_VFS_OK)
 		size = info->size;
 
-	g_free (escaped);
 	gnome_vfs_file_info_unref (info);
 
 	return size;
 }
 
 
-time_t 
-get_file_mtime (const gchar *path)
+time_t
+get_file_mtime (const char *uri)
 {
 	GnomeVFSFileInfo *info;
-	GnomeVFSResult result;
-	gchar *escaped;
-	time_t mtime;
+	GnomeVFSResult    result;
+	time_t            mtime;
 
-	if (! path || ! *path) return 0; 
+	if ((uri == NULL) || (*uri == '\0'))
+		return 0;
 
 	info = gnome_vfs_file_info_new ();
-	escaped = gnome_vfs_escape_path_string (path);
-	result = gnome_vfs_get_file_info (escaped, 
-					  info, 
-					  (GNOME_VFS_FILE_INFO_DEFAULT 
+	result = gnome_vfs_get_file_info (uri,
+					  info,
+					  (GNOME_VFS_FILE_INFO_DEFAULT
 					   | GNOME_VFS_FILE_INFO_FOLLOW_LINKS));
 	mtime = 0;
 	if (result == GNOME_VFS_OK)
 		mtime = info->mtime;
 
-	g_free (escaped);
 	gnome_vfs_file_info_unref (info);
 
 	return mtime;
 }
 
 
-time_t 
-get_file_ctime (const gchar *path)
+time_t
+get_file_ctime (const char *uri)
 {
 	GnomeVFSFileInfo *info;
-	GnomeVFSResult result;
-	gchar *escaped;
-	time_t ctime;
+	GnomeVFSResult    result;
+	time_t            ctime;
 
-	if (! path || ! *path) return 0; 
+	if ((uri == NULL) || (*uri == '\0'))
+		return 0;
 
 	info = gnome_vfs_file_info_new ();
-	escaped = gnome_vfs_escape_path_string (path);
-	result = gnome_vfs_get_file_info (escaped, 
-					  info, 
-					  (GNOME_VFS_FILE_INFO_DEFAULT 
+	result = gnome_vfs_get_file_info (uri,
+					  info,
+					  (GNOME_VFS_FILE_INFO_DEFAULT
 					   | GNOME_VFS_FILE_INFO_FOLLOW_LINKS));
 	ctime = 0;
 	if (result == GNOME_VFS_OK)
 		ctime = info->ctime;
 
-	g_free (escaped);
 	gnome_vfs_file_info_unref (info);
 
 	return ctime;
 }
 
 
-gboolean 
-file_copy (const gchar *from, 
+gboolean
+file_copy (const gchar *from,
 	   const gchar *to)
 {
 	FILE *fin, *fout;
@@ -283,7 +355,7 @@ file_copy (const gchar *from,
 	}
 
 	fin = fopen (from, "rb");
-	if (! fin) 
+	if (! fin)
 		return FALSE;
 
 	dest_dir = remove_level_from_path (to);
@@ -300,7 +372,7 @@ file_copy (const gchar *from,
 		return FALSE;
 	}
 
-	while ((n = fread (buf, sizeof (char), BUF_SIZE, fin)) != 0) 
+	while ((n = fread (buf, sizeof (char), BUF_SIZE, fin)) != 0)
 		if (fwrite (buf, sizeof (char), n, fout) != n) {
 			g_free (dest_dir);
 			fclose (fin);
@@ -317,7 +389,7 @@ file_copy (const gchar *from,
 
 
 gboolean
-file_move (const gchar *from, 
+file_move (const gchar *from,
 	   const gchar *to)
 {
 	if (file_copy (from, to) && ! unlink (from))
@@ -327,7 +399,7 @@ file_move (const gchar *from,
 }
 
 
-gboolean 
+gboolean
 file_is_hidden (const gchar *name)
 {
 	if (name[0] != '.') return FALSE;
@@ -346,7 +418,7 @@ file_name_from_path (const gchar *file_name)
 	register gssize base;
 	register gssize last_char;
 
-	if (file_name == NULL) 
+	if (file_name == NULL)
 		return NULL;
 
 	if (file_name[0] == '\0')
@@ -371,20 +443,20 @@ dir_name_from_path (const gchar *path)
 	register  gssize base;
 	register  gssize last_char;
 
-	if (path == NULL) 
+	if (path == NULL)
 		return NULL;
 
 	if (path[0] == '\0')
 		return g_strdup ("");
 
 	last_char = strlen (path) - 1;
-	if (path[last_char] == G_DIR_SEPARATOR) 
+	if (path[last_char] == G_DIR_SEPARATOR)
 		last_char--;
 
 	base = last_char;
 	while ((base >= 0) && (path[base] != G_DIR_SEPARATOR))
-		base--;	
-	
+		base--;
+
 	return g_strndup (path + base + 1, last_char - base);
 }
 
@@ -392,17 +464,21 @@ dir_name_from_path (const gchar *path)
 gchar *
 remove_level_from_path (const gchar *path)
 {
-	gchar *new_path;
-	const gchar *ptr = path;
-	gint p;
+	int         p;
+	const char *ptr = path;
+	char       *new_path;
 
-	if (! path) return NULL;
+	if (path == NULL)
+		return NULL;
 
 	p = strlen (path) - 1;
-	if (p < 0) return NULL;
+	if (p < 0)
+		return NULL;
 
-	while ((ptr[p] != '/') && (p > 0)) p--;
-	if ((p == 0) && (ptr[p] == '/')) p++;
+	while ((p > 0) && (ptr[p] != '/'))
+		p--;
+	if ((p == 0) && (ptr[p] == '/'))
+		p++;
 	new_path = g_strndup (path, (guint)p);
 
 	return new_path;
@@ -412,23 +488,30 @@ remove_level_from_path (const gchar *path)
 gchar *
 remove_extension_from_path (const gchar *path)
 {
-	gchar *new_path;
-	const gchar *ptr = path;
-	gint p;
+	int         len;
+	int         p;
+	const char *ptr = path;
+	char       *new_path;
 
-	if (!path) return NULL;
-	if (strlen (path) < 2) return g_strdup( path);
+	if (! path)
+		return NULL;
 
-	p = strlen (path) - 1;
-	while ((ptr[p] != '.') && (p > 0)) p--;
-	if (p == 0) p = strlen (path) - 1;
+	len = strlen (path);
+	if (len == 1)
+		return g_strdup (path);
+
+	p = len - 1;
+	while ((p > 0) && (ptr[p] != '.'))
+		p--;
+	if (p == 0)
+		p = len;
 	new_path = g_strndup (path, (guint) p);
 
 	return new_path;
 }
 
 
-gchar * 
+gchar *
 remove_ending_separator (const gchar *path)
 {
 	gint len, copy_len;
@@ -437,14 +520,14 @@ remove_ending_separator (const gchar *path)
 		return NULL;
 
 	copy_len = len = strlen (path);
-	if ((len > 1) && (path[len - 1] == '/')) 
+	if ((len > 1) && (path[len - 1] == '/'))
 		copy_len--;
 
 	return g_strndup (path, copy_len);
 }
 
 
-gboolean 
+gboolean
 ensure_dir_exists (const gchar *a_path,
 		   mode_t       mode)
 {
@@ -453,17 +536,17 @@ ensure_dir_exists (const gchar *a_path,
 	if (! path_is_dir (a_path)) {
 		char *path = g_strdup (a_path);
 		char *p = path;
-		
+
 		while (*p != '\0') {
 			p++;
 			if ((*p == '/') || (*p == '\0')) {
 				gboolean end = TRUE;
-				
+
 				if (*p != '\0') {
 					*p = '\0';
 					end = FALSE;
 				}
-				
+
 				if (! path_is_dir (path)) {
 					if (gnome_vfs_make_directory (path, mode) != GNOME_VFS_OK) {
 						g_warning ("directory creation failed: %s.", path);
@@ -482,14 +565,14 @@ ensure_dir_exists (const gchar *a_path,
 
 
 gboolean
-file_extension_is (const char *filename, 
+file_extension_is (const char *filename,
 		   const char *ext)
 {
 	int filename_l, ext_l;
-	
+
 	filename_l = strlen (filename);
 	ext_l = strlen (ext);
-	
+
 	if (filename_l < ext_l)
 		return FALSE;
 	return strcasecmp (filename + filename_l - ext_l, ext) == 0;
@@ -512,10 +595,10 @@ get_mime_type (const char  *filename)
 void
 path_list_free (GList *path_list)
 {
-	if (path_list != NULL) {
-		g_list_foreach (path_list, (GFunc) g_free, NULL);
-		g_list_free (path_list);
-	}
+	if (path_list == NULL)
+		return;
+	g_list_foreach (path_list, (GFunc) g_free, NULL);
+	g_list_free (path_list);
 }
 
 
@@ -533,20 +616,15 @@ path_list_dup (GList *path_list)
 
 
 GnomeVFSFileSize
-get_dest_free_space (const char  *path)
+get_dest_free_space (const char *uri)
 {
-	char             *escaped;
-	GnomeVFSURI      *uri;
+	GnomeVFSURI      *vfs_uri;
 	GnomeVFSResult    result;
 	GnomeVFSFileSize  ret_val;
 
-	escaped = gnome_vfs_escape_path_string (path);
-	uri = gnome_vfs_uri_new (escaped);
-	g_free (escaped);
-
-	result = gnome_vfs_get_volume_free_space (uri, &ret_val);
-
-	gnome_vfs_uri_unref (uri);
+	vfs_uri = gnome_vfs_uri_new (uri);
+	result = gnome_vfs_get_volume_free_space (vfs_uri, &ret_val);
+	gnome_vfs_uri_unref (vfs_uri);
 
 	if (result != GNOME_VFS_OK)
 		return (GnomeVFSFileSize) 0;
@@ -558,103 +636,239 @@ get_dest_free_space (const char  *path)
 #define SPECIAL_DIR(x) (! strcmp (x, "..") || ! strcmp (x, "."))
 
 
-static gboolean 
-path_list_new (const char  *path, 
-	       GList      **files, 
-	       GList      **dirs)
+static gboolean
+get_directory_content (const char  *uri,
+	       	       GList      **files,
+	               GList      **dirs)
 {
-	DIR *dp;
-	struct dirent *dir;
-	struct stat stat_buf;
-	GList *f_list = NULL;
-	GList *d_list = NULL;
+	GnomeVFSDirectoryHandle *h;
+	GnomeVFSResult           result;
+	GnomeVFSFileInfo        *info;
+	GList                   *f_list = NULL;
+	GList                   *d_list = NULL;
+		
+	if (dirs) 
+		*dirs = NULL;
+	if (files) 
+		*files = NULL;
 
-	dp = opendir (path);
-	if (dp == NULL) return FALSE;
+	result = gnome_vfs_directory_open (&h, uri, GNOME_VFS_FILE_INFO_DEFAULT);
+	if (result != GNOME_VFS_OK)
+		return FALSE;	
 
-	while ((dir = readdir (dp)) != NULL) {
-		gchar *name;
-		gchar *filepath;
-
-		/* Skip removed files */
-		if (dir->d_ino == 0) 
-			continue;
-
-		name = dir->d_name;
-		if (strcmp (path, "/") == 0)
-			filepath = g_strconcat (path, name, NULL);
-		else
-			filepath = g_strconcat (path, "/", name, NULL);
-
-		if (stat (filepath, &stat_buf) >= 0) {
-			if (dirs  
-			    && S_ISDIR (stat_buf.st_mode) 
-			    && ! SPECIAL_DIR (name))
-			{
-				d_list = g_list_prepend (d_list, filepath);
-				filepath = NULL;
-			} else if (files && S_ISREG (stat_buf.st_mode)) {
-				f_list = g_list_prepend (f_list, filepath);
-				filepath = NULL;
+	info = gnome_vfs_file_info_new ();
+	
+	while ((result = gnome_vfs_directory_read_next (h, info)) == GNOME_VFS_OK) {
+		char *entry_uri;
+		char *e_name;
+		
+		e_name = gnome_vfs_escape_string (info->name);
+		entry_uri = g_strconcat (uri, "/", e_name, NULL);
+		g_free (e_name);
+		
+		if (info->type == GNOME_VFS_FILE_TYPE_DIRECTORY) {
+			if (! SPECIAL_DIR (info->name)) {
+				d_list = g_list_prepend (d_list, entry_uri);
+				entry_uri = NULL;
 			}
 		}
-
-		if (filepath) g_free (filepath);
+		else if (info->type == GNOME_VFS_FILE_TYPE_REGULAR) {
+			f_list = g_list_prepend (f_list, entry_uri);
+			entry_uri = NULL;
+		}
+		
+		g_free (entry_uri);	
 	}
-	closedir (dp);
-
-	if (dirs) *dirs = g_list_reverse (d_list);
-	if (files) *files = g_list_reverse (f_list);
+	
+	gnome_vfs_file_info_unref (info);
+	gnome_vfs_directory_close (h);
+	
+	if (dirs) 
+		*dirs = g_list_reverse (d_list);
+	if (files) 
+		*files = g_list_reverse (f_list);
 
 	return TRUE;
 }
 
 
 gboolean
-rmdir_recursive (const gchar *directory)
+remove_directory (const char *uri)
 {
-	GList    *files, *dirs;
-	GList    *scan;
-	gboolean  error = FALSE;
+	GList          *files, *dirs;
+	GList          *scan;
+	gboolean        error = FALSE;
+	GnomeVFSResult  result;
 
-	if (! path_is_dir (directory)) 
+	if (! get_directory_content (uri, &files, &dirs))
 		return FALSE;
 
-	path_list_new (directory, &files, &dirs);
-
 	for (scan = files; scan; scan = scan->next) {
 		char *file = scan->data;
-		if ((unlink (file) < 0)) {
-			g_warning ("Cannot delete %s\n", file);
+		
+		result = gnome_vfs_unlink (file);
+		if (result != GNOME_VFS_OK) {
+			g_warning ("Cannot delete %s: %s\n", file, gnome_vfs_result_to_string (result));
 			error = TRUE;
 		}
 	}
-	path_list_free (files);
 
-	for (scan = dirs; scan; scan = scan->next) {
-		char *sub_dir = scan->data;
-		if (rmdir_recursive (sub_dir) == FALSE)
+	for (scan = dirs; scan; scan = scan->next) 
+		if (! remove_directory ((char*) scan->data))
 			error = TRUE;
-		if (rmdir (sub_dir) == 0)
-			error = TRUE;
-	}
+	
+	path_list_free (files);
 	path_list_free (dirs);
 
-	if (rmdir (directory) == 0)
+	result = gnome_vfs_remove_directory (uri);
+	if (result != GNOME_VFS_OK) {
+		g_warning ("Cannot delete %s: %s\n", uri, gnome_vfs_result_to_string (result));
 		error = TRUE;
+	}
 
-	return !error;
+	return ! error;
+}
+
+
+gboolean
+remove_local_directory (const char *path)
+{
+	char     *uri;
+	gboolean  result;
+	
+	uri = get_uri_from_local_path (path);
+	result = remove_directory (uri);
+	g_free (uri);
+	
+	return result;
+}
+
+
+GnomeVFSResult
+make_tree (const char *uri)
+{
+	char  *root;
+	char **parts;
+	char  *parent;
+	int    i;
+
+	root = get_uri_host (uri);
+	if ((uricmp (root, uri) == 0) || (strlen (uri) <= strlen (root) + 1)) {
+		g_free (root);
+		return GNOME_VFS_OK;
+	}
+
+	parts = g_strsplit (uri + strlen (root) + 1, "/", -1);
+	if ((parts == NULL) || (parts[0] == NULL) || (parts[1] == NULL)) {
+		if (parts != NULL)
+			g_strfreev (parts);
+		g_free (root);
+		return GNOME_VFS_OK;
+	}
+
+	parent = g_strdup (root);
+	for (i = 0; parts[i + 1] != NULL; i++) {
+		char           *tmp;
+		GnomeVFSResult  result;
+
+		tmp = g_strconcat (parent, "/", parts[i], NULL);
+		g_free (parent);
+		parent = tmp;
+
+		result = gnome_vfs_make_directory (parent, 0755);
+		if ((result != GNOME_VFS_OK) && (result != GNOME_VFS_ERROR_FILE_EXISTS)) {
+			g_free (parent);
+			g_strfreev (parts);
+			g_free (root);
+			return result;
+		}
+	}
+
+	g_free (parent);
+	g_strfreev (parts);
+	g_free (root);
+
+	return GNOME_VFS_OK;
+}
+
+
+static const char *try_folder[] = { "~", "tmp", NULL };
+
+
+static const char *
+get_folder_from_try_folder_list (int n)
+{
+	const char *folder;
+
+	folder = try_folder[n];
+	if (strcmp (folder, "~") == 0)
+		folder = g_get_home_dir ();
+	else if (strcmp (folder, "tmp") == 0)
+		folder = g_get_tmp_dir ();
+
+	return folder;
 }
 
 
 char *
 get_temp_work_dir (void)
 {
-	char temp_dir_template[] = "/tmp/fr-XXXXXX";
-	if (mkdtemp (temp_dir_template) == NULL)
-		return NULL;
-	else
-		return g_strdup (temp_dir_template);
+	GnomeVFSFileSize  max_size = 0;
+	char             *best_folder = NULL;
+	int               i;
+	char             *template;
+	char             *result = NULL;
+
+	/* find the folder with more free space. */
+
+	for (i = 0; try_folder[i] != NULL; i++) {
+		const char       *folder;
+		char             *uri;
+		GnomeVFSFileSize  size;
+
+		folder = get_folder_from_try_folder_list (i);
+		uri = g_strconcat ("file://", folder, NULL);
+
+		size = get_dest_free_space (uri);
+		if (max_size < size) {
+			max_size = size;
+			g_free (best_folder);
+			best_folder = uri;
+		}
+		else
+			g_free (uri);
+	}
+
+	template = g_strconcat (best_folder + strlen ("file://"), "/.fr-XXXXXX", NULL);
+	result = mkdtemp (template);
+
+	if ((result == NULL) || (*result == '\0')) {
+		g_free (template);
+		result = NULL;
+	}
+
+	return result;
+}
+
+
+gboolean
+is_temp_work_dir (const char *dir) {
+	int i;
+
+	if (strncmp (dir, "file://", 7) == 0)
+		dir = dir + 7;
+	else if (dir[0] != '/')
+		return FALSE;
+
+	for (i = 0; try_folder[i] != NULL; i++) {
+		const char *folder;
+
+		folder = get_folder_from_try_folder_list (i);
+		if (strncmp (dir, folder, strlen (folder)) == 0)
+			return TRUE;
+	}
+
+	return FALSE;
 }
 
 
@@ -662,7 +876,7 @@ get_temp_work_dir (void)
 
 
 gboolean
-file_list__match_pattern (const char *line, 
+file_list__match_pattern (const char *line,
 			  const char *pattern)
 {
 	const char *l = line, *p = pattern;
@@ -677,11 +891,11 @@ file_list__match_pattern (const char *line,
 			case 'a':
 				break;
 			case 'n':
-				if (!isdigit (*l)) 
+				if (!isdigit (*l))
 					return FALSE;
 				break;
 			case 'c':
-				if (!isalpha (*l)) 
+				if (!isalpha (*l))
 					return FALSE;
 				break;
 			default:
@@ -689,13 +903,13 @@ file_list__match_pattern (const char *line,
 			}
 		}
 	}
-	
+
 	return (*p == 0);
 }
 
 
 int
-file_list__get_index_from_pattern (const char *line, 
+file_list__get_index_from_pattern (const char *line,
 				   const char *pattern)
 {
 	int         line_l, pattern_l;
@@ -707,10 +921,10 @@ file_list__get_index_from_pattern (const char *line,
 	if ((pattern_l == 0) || (line_l == 0))
 		return -1;
 
-	for (l = line; *l != 0; l++) 
+	for (l = line; *l != 0; l++)
 		if (file_list__match_pattern (l, pattern))
 			return (l - line);
-	
+
 	return -1;
 }
 
@@ -721,9 +935,9 @@ file_list__get_next_field (const char *line,
 			   int         field_n)
 {
 	const char *f_start, *f_end;
-	
+
 	line = line + start_from;
-	
+
 	f_start = line;
 	while ((*f_start == ' ') && (*f_start != *line))
 		f_start++;
@@ -740,7 +954,7 @@ file_list__get_next_field (const char *line,
 		} else
 			f_end++;
 	}
-	
+
 	return g_strndup (f_start, f_end - f_start);
 }
 
@@ -788,13 +1002,14 @@ escape_uri (const char *uri)
 	if (start != NULL) {
 		uri_no_method = start + strlen ("://");
 		method = g_strndup (uri, start - uri);
-	} else {
+	} 
+	else {
 		uri_no_method = uri;
 		method = NULL;
 	}
-	
+
 	epath = gnome_vfs_escape_host_and_path_string (uri_no_method);
-	
+
 	if (method != NULL) {
 		euri = g_strdup_printf ("%s://%s", method, epath);
 		g_free (epath);
@@ -808,60 +1023,243 @@ escape_uri (const char *uri)
 
 
 gboolean
-check_permissions (const char *path,
-		   int         mode) 
+check_permissions (const char *uri,
+		   int         mode)
 {
 	GnomeVFSFileInfo *info;
 	GnomeVFSResult    vfs_result;
-	char             *escaped;
+	gboolean          result = TRUE;
 
 	info = gnome_vfs_file_info_new ();
-	escaped = escape_uri (path);
-	vfs_result = gnome_vfs_get_file_info (escaped, 
-					      info, 
-					      (GNOME_VFS_FILE_INFO_DEFAULT 
-					       | GNOME_VFS_FILE_INFO_FOLLOW_LINKS
+	vfs_result = gnome_vfs_get_file_info (uri,
+					      info,
+					      (GNOME_VFS_FILE_INFO_FOLLOW_LINKS
 					       | GNOME_VFS_FILE_INFO_GET_ACCESS_RIGHTS));
-	g_free (escaped);
 
-	if (vfs_result != GNOME_VFS_OK) 
-		return FALSE; 
+	if (vfs_result != GNOME_VFS_OK)
+		result = FALSE;
 
-	if ((mode & R_OK) && ! (info->permissions & GNOME_VFS_PERM_ACCESS_READABLE)) 
-		return FALSE; 
+	else if ((mode & R_OK) && ! (info->permissions & GNOME_VFS_PERM_ACCESS_READABLE))
+		result = FALSE;
 
-	if ((mode & W_OK) && ! (info->permissions & GNOME_VFS_PERM_ACCESS_WRITABLE)) 
-		return FALSE; 
+	else if ((mode & W_OK) && ! (info->permissions & GNOME_VFS_PERM_ACCESS_WRITABLE))
+		result = FALSE;
 
-	if ((mode & X_OK) && ! (info->permissions & GNOME_VFS_PERM_ACCESS_WRITABLE)) 
-		return FALSE; 
+	else if ((mode & X_OK) && ! (info->permissions & GNOME_VFS_PERM_ACCESS_EXECUTABLE))
+		result = FALSE;
+
+	gnome_vfs_file_info_unref (info);
 
 	return TRUE;
 }
 
 
-gboolean 
+gboolean
 is_program_in_path (const char *filename)
 {
-        char *str;
+	char *str;
 	char *value;
 	int   result = FALSE;
 
-	value = g_hash_table_lookup (programs_cache, filename);
+	value = g_hash_table_lookup (ProgramsCache, filename);
 	if (value != NULL) {
 		result = (strcmp (value, "1") == 0);
 		return result;
 	}
 
-        str = g_find_program_in_path (filename);
-        if (str != NULL) {
-                g_free (str);
+	str = g_find_program_in_path (filename);
+	if (str != NULL) {
+		g_free (str);
 		result = TRUE;
-        }
+	}
 
-	g_hash_table_insert (programs_cache, 
-			     g_strdup (filename), 
+	g_hash_table_insert (ProgramsCache,
+			     g_strdup (filename),
 			     result ? "1" : "0");
+
+	return result;
+}
+
+
+const char *
+get_home_uri (void)
+{
+	static char *home_uri = NULL;
+	if (home_uri == NULL)
+		home_uri = g_strconcat ("file://", g_get_home_dir (), NULL);
+	return home_uri;
+}
+
+
+GnomeVFSURI *
+new_uri_from_path (const char *path)
+{
+	char        *uri_txt;
+	GnomeVFSURI *uri;
+
+	uri_txt = get_uri_from_local_path (path);
+	uri = gnome_vfs_uri_new (uri_txt);
+	g_free (uri_txt);
+
+	g_return_val_if_fail (uri != NULL, NULL);
+
+	return uri;
+}
+
+
+char *
+get_uri_from_local_path (const char *local_path)
+{
+	char *escaped;
+	char *uri;
+
+	escaped = escape_uri (local_path);
+	if (escaped[0] == '/') {
+		uri = g_strconcat ("file://", escaped, NULL);
+		g_free (escaped);
+	}
+	else
+		uri = escaped;
+
+	return uri;
+}
+
+
+char *
+get_local_path_from_uri (const char *uri)
+{
+	return gnome_vfs_unescape_string (remove_host_from_uri (uri), NULL);
+}
+
+
+gboolean
+uri_has_scheme (const char *uri)
+{
+	return strstr (uri, "://") != NULL;
+}
+
+
+gboolean
+uri_is_local (const char *uri)
+{
+	GnomeVFSURI *vfs_uri;
+	gboolean     is_local;
+
+	vfs_uri = new_uri_from_path (uri);
+	g_return_val_if_fail (vfs_uri != NULL, FALSE);
+
+	is_local = gnome_vfs_uri_is_local (vfs_uri);
+	gnome_vfs_uri_unref (vfs_uri);
+
+	return is_local;
+}
+
+
+const char *
+remove_host_from_uri (const char *uri)
+{
+	const char *idx;
+
+	idx = strstr (uri, "://");
+	if (idx == NULL)
+		return uri;
+	idx = strstr (idx + 3, "/");
+	if (idx == NULL)
+		return NULL;
+	return idx;
+}
+
+
+char *
+get_uri_host (const char *uri)
+{
+	const char *idx;
+
+	idx = strstr (uri, "://");
+	if (idx == NULL)
+		return NULL;
+	idx = strstr (idx + 3, "/");
+	if (idx == NULL)
+		return NULL;
+	return g_strndup (uri, (idx - uri));
+}
+
+
+char *
+get_uri_root (const char *uri)
+{
+	char *host;
+	char *root;
+
+	host = get_uri_host (uri);
+	if (host == NULL)
+		return NULL;
+	root = g_strconcat (host, "/", NULL);
+	g_free (host);
+
+	return root;
+}
+
+
+char *
+get_uri_from_path (const char *path)
+{
+	if (path == NULL)
+		return NULL;
+	if ((path == "") || (path[0] == '/'))
+		return g_strconcat ("file://", path, NULL);
+	return g_strdup (path);
+}
+
+
+int
+uricmp (const char *path1,
+	const char *path2)
+{
+	char *uri1, *uri2;
+	int   result;
+
+	uri1 = get_uri_from_path (path1);
+	uri2 = get_uri_from_path (path2);
+
+	result = strcmp_null_tollerant (uri1, uri2);
+
+	g_free (uri1);
+	g_free (uri2);
+
+	return result;
+}
+
+
+char *
+get_new_uri (const char *folder,
+	     const char *name)
+{
+	char *new_uri = NULL;
+	int   n = 1;
 	
-        return result;
+	do {
+		g_free (new_uri);
+		if (n == 1)
+			new_uri = g_strconcat (folder, "/", name, NULL);
+		else
+			new_uri = g_strdup_printf ("%s/%s%%20(%d)", folder, name, n);
+		n++;
+	} while (uri_exists (new_uri));
+	
+	return new_uri;	
+}
+
+
+char *
+get_new_uri_from_uri (const char *uri)
+{
+	char *base_uri;
+	char *new_uri;
+	
+	base_uri = remove_level_from_path (uri);
+	new_uri = get_new_uri (base_uri, file_name_from_path (uri));
+	g_free (base_uri);
+	
+	return new_uri;
 }
