@@ -25,8 +25,6 @@
 #include <time.h>
 
 #include <glib.h>
-#include <libgnomevfs/gnome-vfs-types.h>
-#include <libgnomevfs/gnome-vfs-mime.h>
 
 #include "file-data.h"
 #include "file-utils.h"
@@ -34,13 +32,13 @@
 #include "fr-command.h"
 #include "fr-command-lha.h"
 
-static void fr_command_lha_class_init  (FRCommandLhaClass *class);
-static void fr_command_lha_init        (FRCommand         *afile);
+static void fr_command_lha_class_init  (FrCommandLhaClass *class);
+static void fr_command_lha_init        (FrCommand         *afile);
 static void fr_command_lha_finalize    (GObject           *object);
 
 /* Parent Class */
 
-static FRCommandClass *parent_class = NULL;
+static FrCommandClass *parent_class = NULL;
 
 
 /* -- list -- */
@@ -157,7 +155,7 @@ process_line (char     *line,
 	      gpointer  data)
 {
 	FileData    *fdata;
-	FRCommand   *comm = FR_COMMAND (data);
+	FrCommand   *comm = FR_COMMAND (data);
 	char       **fields;
 	const char  *name_field;
 
@@ -202,7 +200,7 @@ process_line (char     *line,
 
 
 static void
-fr_command_lha_list (FRCommand  *comm,
+fr_command_lha_list (FrCommand  *comm,
 		     const char *password)
 {
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
@@ -218,7 +216,7 @@ fr_command_lha_list (FRCommand  *comm,
 
 
 static void
-fr_command_lha_add (FRCommand     *comm,
+fr_command_lha_add (FrCommand     *comm,
 		    GList         *file_list,
 		    const char    *base_dir,
 		    gboolean       update,
@@ -242,7 +240,7 @@ fr_command_lha_add (FRCommand     *comm,
 
 
 static void
-fr_command_lha_delete (FRCommand *comm,
+fr_command_lha_delete (FrCommand *comm,
 		       GList     *file_list)
 {
 	GList *scan;
@@ -258,7 +256,7 @@ fr_command_lha_delete (FRCommand *comm,
 
 
 static void
-fr_command_lha_extract (FRCommand  *comm,
+fr_command_lha_extract (FrCommand  *comm,
 			GList      *file_list,
 			const char *dest_dir,
 			gboolean    overwrite,
@@ -297,13 +295,13 @@ fr_command_lha_extract (FRCommand  *comm,
 
 
 static void 
-fr_command_lha_class_init (FRCommandLhaClass *class)
+fr_command_lha_class_init (FrCommandLhaClass *class)
 {
         GObjectClass   *gobject_class = G_OBJECT_CLASS (class);
-        FRCommandClass *afc;
+        FrCommandClass *afc;
 
         parent_class = g_type_class_peek_parent (class);
-	afc = (FRCommandClass*) class;
+	afc = (FrCommandClass*) class;
 
 	gobject_class->finalize = fr_command_lha_finalize;
 
@@ -315,7 +313,7 @@ fr_command_lha_class_init (FRCommandLhaClass *class)
 
  
 static void 
-fr_command_lha_init (FRCommand *comm)
+fr_command_lha_init (FrCommand *comm)
 {
 	comm->file_type = FR_FILE_TYPE_LHA;
 
@@ -349,13 +347,13 @@ fr_command_lha_get_type ()
 
         if (! type) {
                 GTypeInfo type_info = {
-			sizeof (FRCommandLhaClass),
+			sizeof (FrCommandLhaClass),
 			NULL,
 			NULL,
 			(GClassInitFunc) fr_command_lha_class_init,
 			NULL,
 			NULL,
-			sizeof (FRCommandLha),
+			sizeof (FrCommandLha),
 			0,
 			(GInstanceInitFunc) fr_command_lha_init
 		};
@@ -370,11 +368,11 @@ fr_command_lha_get_type ()
 }
 
 
-FRCommand *
-fr_command_lha_new (FRProcess  *process,
+FrCommand *
+fr_command_lha_new (FrProcess  *process,
 		    const char *filename)
 {
-	FRCommand *comm;
+	FrCommand *comm;
 
 	if (!is_program_in_path("lha")) {
 		return NULL;
