@@ -28,29 +28,42 @@
 #include "fr-process.h"
 
 #define FR_TYPE_COMMAND            (fr_command_get_type ())
-#define FR_COMMAND(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), FR_TYPE_COMMAND, FRCommand))
-#define FR_COMMAND_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), FR_TYPE_COMMAND, FRCommandClass))
+#define FR_COMMAND(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), FR_TYPE_COMMAND, FrCommand))
+#define FR_COMMAND_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), FR_TYPE_COMMAND, FrCommandClass))
 #define FR_IS_COMMAND(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FR_TYPE_COMMAND))
 #define FR_IS_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), FR_TYPE_COMMAND))
-#define FR_COMMAND_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), FR_TYPE_COMMAND, FRCommandClass))
+#define FR_COMMAND_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), FR_TYPE_COMMAND, FrCommandClass))
 
-typedef struct _FRCommand       FRCommand;
-typedef struct _FRCommandClass  FRCommandClass;
+typedef struct _FrCommand       FrCommand;
+typedef struct _FrCommandClass  FrCommandClass;
 
 typedef enum {
 	FR_ACTION_NONE,
-	FR_ACTION_LIST,
-	FR_ACTION_ADD,
-	FR_ACTION_DELETE,
-	FR_ACTION_EXTRACT,
-	FR_ACTION_TEST,
-	FR_ACTION_GET_LIST,
-	FR_ACTION_SAVE
+	FR_ACTION_CREATING_NEW_ARCHIVE,
+	FR_ACTION_LOADING_ARCHIVE,            /* loading the archive from a remote location */
+	FR_ACTION_LISTING_CONTENT,            /* listing the content of the archive */
+	FR_ACTION_DELETING_FILES,             /* deleting files from the archive */
+	FR_ACTION_TESTING_ARCHIVE,            /* testing the archive integrity */
+	FR_ACTION_GETTING_FILE_LIST,          /* getting the file list (when fr_archive_add_with_wildcard or
+						 fr_archive_add_directory are used, we need to scan a directory
+						 and collect the files to add to the archive, this
+						 may require some time to complete, so the operation
+						 is asynchronous) */
+	FR_ACTION_COPYING_FILES_FROM_REMOTE,  /* copying files to be added to the archive from a remote location */
+	FR_ACTION_ADDING_FILES,               /* adding files to an archive */
+	FR_ACTION_EXTRACTING_FILES,           /* extracting files */
+	FR_ACTION_COPYING_FILES_TO_REMOTE,    /* copying extracted files to a remote location */
+	FR_ACTION_CREATING_ARCHIVE,           /* creating a local archive */
+	FR_ACTION_SAVING_REMOTE_ARCHIVE       /* copying the archive to a remote location */
 } FRAction;
 
-struct _FRCommand
+#ifdef DEBUG
+extern char *action_names[];
+#endif
+
+struct _FrCommand
 {
-        GObject  __parent;
+	GObject  __parent;
 
 	FRFileType  file_type;
 	GList      *file_list;       /* FileData elements */
@@ -62,6 +75,7 @@ struct _FRCommand
 	guint propCanModify : 1;
 	guint propAddCanUpdate : 1;
 	guint propAddCanReplace : 1;
+	guint propAddCanStoreFolders : 1;
 	guint propExtractCanAvoidOverwrite : 1;
 	guint propExtractCanSkipOlder : 1;
 	guint propExtractCanJunkPaths : 1;
@@ -76,36 +90,36 @@ struct _FRCommand
 
 	/*<private>*/
 
-	FRProcess *process;      /* the process object used to execute 
+	FrProcess *process;      /* the process object used to execute
 				  * commands. */
 	FRAction   action;       /* current action. */
 	char      *filename;     /* archive filename. */
 	char      *e_filename;   /* escaped archive filename. */
 
-	gboolean   fake_load;    /* if TRUE does nothing when the list 
+	gboolean   fake_load;    /* if TRUE does nothing when the list
 				  * operation is invoked. */
 };
 
-struct _FRCommandClass
+struct _FrCommandClass
 {
-        GObjectClass __parent_class;
+	GObjectClass __parent_class;
 
 	/*<virtual functions>*/
 
-	void        (*list)           (FRCommand     *comm,
+	void        (*list)           (FrCommand     *comm,
 				       const char    *password);
 
-	void        (*add)            (FRCommand     *comm,
+	void        (*add)            (FrCommand     *comm,
 				       GList         *file_list,
 				       const char    *base_dir,
 				       gboolean       update,
 				       const char    *password,
 				       FRCompression  compression); 
 
-	void        (*delete)         (FRCommand     *comm,
+	void        (*delete)         (FrCommand     *comm,
 				       GList         *file_list); 
 
-	void        (*extract)        (FRCommand     *comm,
+	void        (*extract)        (FrCommand     *comm,
 				       GList         *file_list,
 				       const char    *dest_dir,
 				       gboolean       overwrite,
@@ -113,59 +127,59 @@ struct _FRCommandClass
 				       gboolean       junk_paths,
 				       const char    *password);
 
-	void        (*test)           (FRCommand     *comm,
+	void        (*test)           (FrCommand     *comm,
 				       const char    *password);
 
-	void        (*uncompress)     (FRCommand     *comm);
+	void        (*uncompress)     (FrCommand     *comm);
 
-	void        (*recompress)     (FRCommand     *comm,
+	void        (*recompress)     (FrCommand     *comm,
 				       FRCompression  compression);
 
-	void        (*handle_error)   (FRCommand     *comm,
+	void        (*handle_error)   (FrCommand     *comm,
 				       FRProcError   *error);
 
-	char *      (*escape)         (FRCommand     *comm,
+	char *      (*escape)         (FrCommand     *comm,
 				       const char    *str);
 
 	/*<signals>*/
 
-	void        (*start)          (FRCommand   *comm,
+	void        (*start)          (FrCommand   *comm,
 				       FRAction     action); 
 
-	void        (*done)           (FRCommand   *comm,
+	void        (*done)           (FrCommand   *comm,
 				       FRAction     action,
 				       FRProcError *error);
 
-        void        (*progress)       (FRCommand   *comm,
+	void        (*progress)       (FrCommand   *comm,
 				       double       fraction);
 
-        void        (*message)        (FRCommand   *comm,
+	void        (*message)        (FrCommand   *comm,
 				       const char  *msg);
 };
 
 GType          fr_command_get_type           (void);
 
-void           fr_command_construct          (FRCommand     *comm,
-					      FRProcess     *process,
+void           fr_command_construct          (FrCommand     *comm,
+					      FrProcess     *process,
 					      const char    *filename);
 
-void           fr_command_set_filename       (FRCommand     *comm,
+void           fr_command_set_filename       (FrCommand     *comm,
 					      const char    *filename);
 
-void           fr_command_list               (FRCommand     *comm,
+void           fr_command_list               (FrCommand     *comm,
 					      const char    *password);
 
-void           fr_command_add                (FRCommand     *comm,
+void           fr_command_add                (FrCommand     *comm,
 					      GList         *file_list,
 					      const char    *base_dir,
 					      gboolean       update,
 					      const char    *password,
 					      FRCompression  compression); 
 
-void           fr_command_delete             (FRCommand     *comm,
+void           fr_command_delete             (FrCommand     *comm,
 					      GList         *file_list); 
 
-void           fr_command_extract            (FRCommand     *comm,
+void           fr_command_extract            (FrCommand     *comm,
 					      GList         *file_list,
 					      const char    *dest_dir,
 					      gboolean       overwrite,
@@ -173,31 +187,31 @@ void           fr_command_extract            (FRCommand     *comm,
 					      gboolean       junk_paths,
 					      const char    *password);
 
-void           fr_command_test               (FRCommand     *comm,
+void           fr_command_test               (FrCommand     *comm,
 					      const char    *password);
 
-void           fr_command_uncompress         (FRCommand     *comm);
+void           fr_command_uncompress         (FrCommand     *comm);
 
-void           fr_command_recompress         (FRCommand     *comm,
+void           fr_command_recompress         (FrCommand     *comm,
 					      FRCompression  compression);
 
-char *         fr_command_escape             (FRCommand     *comm,
+char *         fr_command_escape             (FrCommand     *comm,
 					      const char    *str);
 
 /* protected functions */
 
-void           fr_command_progress           (FRCommand     *comm,
+void           fr_command_progress           (FrCommand     *comm,
 					      double         fraction);
 
-void           fr_command_message            (FRCommand     *comm,
+void           fr_command_message            (FrCommand     *comm,
 					      const char    *msg);
 
-void           fr_command_set_n_files        (FRCommand     *comm,
+void           fr_command_set_n_files        (FrCommand     *comm,
 					      int            n_files);
 
 /* private functions */
 
-void           fr_command_handle_error       (FRCommand     *comm,
+void           fr_command_handle_error       (FrCommand     *comm,
 					      FRProcError   *error);
 
 #endif /* FR_COMMAND_H */
