@@ -42,11 +42,11 @@ static GtkActionEntry action_entries[] = {
 	  NULL, NULL,
 	  N_("Information about the program"),
 	  G_CALLBACK (activate_action_about) },
-	{ "AddFiles", FR_STOCK_ADD,
+	{ "AddFiles", FR_STOCK_ADD_FILES,
 	  N_("_Add Files..."), NULL,
 	  N_("Add files to the archive"),
 	  G_CALLBACK (activate_action_add_files) },
-	{ "AddFiles_Toolbar", FR_STOCK_ADD,
+	{ "AddFiles_Toolbar", FR_STOCK_ADD_FILES,
 	  N_("Add Files"), NULL,
 	  N_("Add files to the archive"),
 	  G_CALLBACK (activate_action_add_files) },
@@ -63,7 +63,7 @@ static GtkActionEntry action_entries[] = {
 	  N_("Close the current archive"),
 	  G_CALLBACK (activate_action_close) },
 	{ "Contents", GTK_STOCK_HELP,
-	  NULL, "F1",
+	  N_("Contents"), "F1",
 	  N_("Display the File Roller Manual"),
 	  G_CALLBACK (activate_action_manual) },
 	{ "Copy", GTK_STOCK_COPY,
@@ -122,10 +122,6 @@ static GtkActionEntry action_entries[] = {
 	  NULL, NULL,
 	  N_("Show archive properties"),
 	  G_CALLBACK (activate_action_properties) },
-	{ "Quit", GTK_STOCK_QUIT,
-	  NULL, NULL,
-	  N_("Quit the application"),
-	  G_CALLBACK (activate_action_quit) },
 	{ "Reload", GTK_STOCK_REFRESH,
 	  NULL, "<control>R",
 	  N_("Reload current archive"),
@@ -151,13 +147,17 @@ static GtkActionEntry action_entries[] = {
 	  N_("Test whether the archive contains errors"),
 	  G_CALLBACK (activate_action_test_archive) },
 	{ "ViewSelection", FR_STOCK_VIEW,
-	  N_("_View"), NULL,
+	  NULL, NULL,
 	  N_("View the selected file"),
 	  G_CALLBACK (activate_action_view_or_open) },
 	{ "ViewSelection_Toolbar", FR_STOCK_VIEW,
-	  N_("_View"), NULL,
+	  NULL, NULL,
 	  N_("View the selected file"),
 	  G_CALLBACK (activate_action_view_or_open) },
+	{ "OpenFolder", GTK_STOCK_OPEN,
+	  NULL, NULL,
+	  N_("Open the selected folder"),
+	  G_CALLBACK (activate_action_open_folder) },
 };
 static guint n_action_entries = G_N_ELEMENTS (action_entries);
 
@@ -185,10 +185,10 @@ static guint n_action_toggle_entries = G_N_ELEMENTS (action_toggle_entries);
 static GtkRadioActionEntry view_as_entries[] = {
 	{ "ViewAllFiles", NULL,
 	  N_("View All _Files"), NULL,
-	  " ", WINDOW_LIST_MODE_FLAT },
+	  " ", FR_WINDOW_LIST_MODE_FLAT },
 	{ "ViewAsFolder", NULL,
 	  N_("View as a F_older"), NULL,
-	  " ", WINDOW_LIST_MODE_AS_DIR },
+	  " ", FR_WINDOW_LIST_MODE_AS_DIR },
 };
 static guint n_view_as_entries = G_N_ELEMENTS (view_as_entries);
 
@@ -196,19 +196,19 @@ static guint n_view_as_entries = G_N_ELEMENTS (view_as_entries);
 static GtkRadioActionEntry sort_by_entries[] = {
 	{ "SortByName", NULL,
 	  N_("by _Name"), NULL,
-	  N_("Sort file list by name"), WINDOW_SORT_BY_NAME },
+	  N_("Sort file list by name"), FR_WINDOW_SORT_BY_NAME },
 	{ "SortBySize", NULL,
 	  N_("by _Size"), NULL,
-	  N_("Sort file list by file size"), WINDOW_SORT_BY_SIZE },
+	  N_("Sort file list by file size"), FR_WINDOW_SORT_BY_SIZE },
 	{ "SortByType", NULL,
 	  N_("by T_ype"), NULL,
-	  N_("Sort file list by type"), WINDOW_SORT_BY_TYPE },
+	  N_("Sort file list by type"), FR_WINDOW_SORT_BY_TYPE },
 	{ "SortByDate", NULL,
 	  N_("by _Date modified"), NULL,
-	  N_("Sort file list by modification time"), WINDOW_SORT_BY_TIME },
+	  N_("Sort file list by modification time"), FR_WINDOW_SORT_BY_TIME },
 	{ "SortByLocation", NULL,
 	  N_("by _Location"), NULL,
-	  N_("Sort file list by location"), WINDOW_SORT_BY_PATH },
+	  N_("Sort file list by location"), FR_WINDOW_SORT_BY_PATH },
 };
 static guint n_sort_by_entries = G_N_ELEMENTS (sort_by_entries);
 
@@ -230,7 +230,6 @@ static const gchar *ui_info =
 "      <menuitem action='Properties'/>"
 "      <separator/>"
 "      <menuitem action='Close'/>"
-"      <menuitem action='Quit'/>"
 "    </menu>"
 "    <menu action='EditMenu'>"
 "      <menuitem action='AddFiles'/>"
@@ -284,7 +283,7 @@ static const gchar *ui_info =
 "    <separator/>"
 "    <toolitem action='Stop'/>"
 "  </toolbar>"
-"  <popup name='ListPopupMenu'>"
+"  <popup name='FilePopupMenu'>"
 "    <menuitem action='ViewSelection'/>"
 "    <menuitem action='OpenSelection'/>"
 "    <separator/>"
@@ -296,6 +295,17 @@ static const gchar *ui_info =
 "    <menuitem action='Rename'/>"
 "    <menuitem action='Delete'/>"
 "  </popup>"
+"  <popup name='FolderPopupMenu'>"
+"    <menuitem action='OpenFolder'/>"
+"    <separator/>"
+"    <menuitem action='Extract'/>"
+"    <separator/>"
+"    <menuitem action='Cut'/>"
+"    <menuitem action='Copy'/>"
+"    <menuitem action='Paste'/>"
+"    <menuitem action='Rename'/>"
+"    <menuitem action='Delete'/>"
+"  </popup>"
 "  <popup name='AddMenu'>"
 "    <menuitem action='AddFiles'/>"
 "    <menuitem action='AddFolder'/>"
